# Creating a dataframe to collect contribution and rank of 
# single variables of the final BRT model
# 
# Author: Johannes Radinger
###############################################################################


# Create dataframe for plotting
library("reshape")
library("plyr")
library("xlsx")

#Resultsdir
maindir <- "/path/to/data/Treene/SDM_Fidimo_Treene/SDM/"
results_dir <- paste(maindir,"Results/",sep="")
predictors_dir <- paste(maindir,"Predictors/",sep="")
fish_dir <- "/path/to/data/Treene/Fish_Data/"

####### Complete array of variable contribution ###########

# Get list of all predictor variables (A=MV=measured variables; B/FE=AV=assessed variables)
pred.Set.A <- list.files(path=paste(predictors_dir,"Set_A_point",sep=""),recursive=TRUE,full.names=FALSE,include.dirs=FALSE)
pred.Set.B <- list.files(path=paste(predictors_dir,"Set_B_point",sep=""),recursive=TRUE,full.names=FALSE,include.dirs=FALSE)
pred.Set.FE <- pred.Set.B[grepl(x=pred.Set.B,pattern="rast_F_")]
pred.Stream.topology <- c("orast_Treene_Shreve.tif","orast_Treene_Strahler.tif","rast_Treene_distance")

pred.all <-c(pred.Set.A,pred.Set.FE,pred.Stream.topology)

# Strip rast/orast/.tif
pred.all <- sub(pattern="orast_*","",pred.all)
pred.all <- sub(pattern="rast_*","",pred.all)
pred.all <- sub(pattern="*.tif","",pred.all)


# maximum variable rank
var.rank <- length(pred.Set.A)+length(pred.Stream.topology)


# Get list of all species
species.list <- list.dirs(path=paste(results_dir,"Set_A_d1000bar",sep=""),full.names=FALSE,recursive=FALSE)


# Array: Predictor x distance x species x model x variable rank x Set_habitat x Set_topology
VC.array <- array(0,   dim = c(length(pred.all),		# predictors
                               5, 						# distance
                               length(species.list), 	# species
                               var.rank, 		# variable rank
                               2,						#  set.habitat
                               2),						#  set.topology
                  dimnames=list(predictors = pred.all,			# predictors
                                distance = c("point","d200bar","d1000bar","d2500bar","d4000bar"),	# distance
                                species = species.list,		# species
                                variable.rank = seq(1:var.rank),  #variable rank
                                set.habitat = c("A","FE"),			# set.habitat
                                set.topology = c("no","+")	)	)	# set.topology
                                
VC.array <- array(0,   dim = c(length(pred.all),5,length(species.list), var.rank,2,2),dimnames=list(predictors = pred.all,                         distance = c("point","d200bar","d1000bar","d2500bar","d4000bar"),species = species.list, variable.rank = seq(1:var.rank), set.habitat = c("A","FE"),set.topology = c("no","+")))


# loop over stats.final files and extract necessary information
stats.final.files <- list.files(path=paste(results_dir,sep=""),recursive=TRUE,full.names=FALSE,pattern = "stats.final",include.dirs=FALSE)
stats.final.files <- stats.final.files[!grepl(x=stats.final.files,pattern="Old_Results")]
stats.final.files <- stats.final.files[grepl(x=stats.final.files,pattern="bar/|point")]
stats.final.files <- stats.final.files[!grepl(x=stats.final.files,pattern="Set_B")]

for(i in stats.final.files){
  path.split <- unlist(strsplit(i,"/"))
  distance <- unlist(strsplit(path.split[1],"_"))[3]
  species <- path.split[2]
  set <- unlist(strsplit(path.split[1],"_"))[2]
  set.habitat <- sub("[+]","",set)
  
  if(grepl("[+]",set)){
    set.topology <- "+"} else {set.topology <- "no"}
  
  stats.final <- readRDS(paste(results_dir,i,sep=""))
  
  for(j in 1:nrow(stats.final$Variable.contribution)){
    predictor.name <- as.character(stats.final$Variable.contribution[j,"var"])
    # Strip of distance and rast/crast !!!!!
    split.predictor.name <- unlist(strsplit(predictor.name,"_"))
    predictors <- paste(split.predictor.name[-which(split.predictor.name %in% c("d200bar","d1000bar","d2500bar","d4000bar","rast","orast"))],collapse="_")
    print(distance)
    variable.contribution <- stats.final$Variable.contribution[j,"rel.inf"]
    
    # Populate VC array
    VC.array[predictors,distance,species,j,set.habitat,set.topology] <- variable.contribution
  }
}


VC.array[is.na(VC.array)] <- 0

# Collapse variable rank (sum)
VC.array.collapse <- apply(VC.array,c(1,2,3,5,6),sum)


# Melt array to dataframe
VC.melt <- melt(VC.array.collapse)
VC.melt.rank <- melt(VC.array)


# Load variable description and Fishnames
predictor.list.extended <-read.xlsx(paste(predictors_dir,"Predictor_list.xlsx",sep=""),
                                    sheetName="Set_A_B",header=T,colIndex=c(1:9))
Fischnamen <-read.xlsx(paste(fish_dir,"Befischungsdaten_Treene_orig.xls",sep=""),
                       sheetName="Fischnamen",header=T,colClasses=c("character","character","character"))
Fischnamen$Name <- gsub(" ",".",Fischnamen$Name)

# Merge dataframe with varibale contribution with dataframe with extended variable description
VC.merge.pred <- merge(VC.melt,predictor.list.extended,by="predictors")
VC.merge.pred.spec <- merge(x=VC.merge.pred,y=Fischnamen,by.x="species",by.y="Name")

VC.rank.merge.pred <- merge(VC.melt.rank,predictor.list.extended,by="predictors")
VC.rank.merge.pred.spec <- merge(x=VC.rank.merge.pred,y=Fischnamen,by.x="species",by.y="Name")
VC.df.rank <- VC.rank.merge.pred.spec

# Delete unpossible combinations of variables in datasets
VC.df <- VC.merge.pred.spec[
  (as.character(VC.merge.pred.spec$set.habitat)==as.character(VC.merge.pred.spec$dataset) | 
     (as.character(VC.merge.pred.spec$dataset)=="topo" & (as.character(VC.merge.pred.spec$set.topology)=="+"))),]


saveRDS(VC.df, file = paste(results_dir,"VC.df.rds",sep="")) 
saveRDS(VC.df.rank, file = paste(results_dir,"VC.df.rank.rds",sep="")) 

