# Analysing dataframe of the contribution of 
# single variables of the final BRT models
# 
# Author: Johannes Radinger
###############################################################################



##### Analyse VARIABLE CONTRIBUTION #######
library(reshape2)
library(xlsx)
library(plyr)

#Resultsdir
maindir <- "path/to/data/Treene/SDM_Treene/SDM_BRT_Treene/"
results_dir <- paste(maindir,"Results/",sep="")


VC.df <- readRDS(file = paste(results_dir,"VC.df.rds",sep=""))
# A=MV=measured variables; FE=AV=assessed variables
VC.df$set.habitat <- factor(VC.df$set.habitat,
                            levels = c("A","FE"),
                            labels = c("MV","AV"))
VC.df$distance <- factor(VC.df$distance,
                                     levels=c("point","d200bar","d1000bar","d2500bar","d4000bar"),
                                     labels=c("0","200","1000","2500","4000"))
head(VC.df)


####### Without  or Without topology ##########
df.comparison <- droplevels(VC.df[VC.df$set.topology=="+",])
head(df.comparison)

plot.VC.comparison1 <- ggplot(df.comparison,aes(x=Var_Group, y=value))+
  geom_jitter(position=position_jitter(width=.2),alpha=0.3)+
  geom_boxplot(fatten=1,outlier.size=0,alpha=0.8)+
  #scale_y_continuous("% Variable contribution",trans="sqrt",breaks=c(1,10,25,50),labels=c(1,10,25,50))+
  #scale_x_discrete(labels="")+
  #facet_grid(~Var_Group)+
  scale_fill_grey(start=0.7, end=1)+
  theme_bw()+
  theme(legend.position = "bottom",
        legend.direction = "horizontal",
        legend.title = element_blank(),
        axis.title.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.text.x = element_text(angle=90, hjust=1, vjust=0.5),
        panel.grid.major = element_blank(),
        panel.grid.minor= element_blank())

plot.VC.comparison2 <- ggplot(df.comparison,aes(x=Var_Group, y=value))+
  geom_jitter(position=position_jitter(width=.2),alpha=0.3)+
  geom_boxplot(fatten=1,outlier.size=0,alpha=0.8)+
  scale_y_continuous("% Variable contribution",trans="sqrt",breaks=c(1,10,25,50),labels=c(1,10,25,50))+
  #scale_x_discrete(labels="")+
  facet_grid(distance~.)+
  scale_fill_grey(start=0.7, end=1)+
  theme_bw()+
  theme(legend.position = "bottom",
        legend.direction = "horizontal",
        legend.title = element_blank(),
        axis.title.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.text.x = element_text(angle=90, hjust=1, vjust=0.5),
        panel.grid.major = element_blank(),
        panel.grid.minor= element_blank())


### Comparison of Variable Groups
kruskal.test(value~Var_Group,df.comparison) # p-value < 2.2e-16 --> Var.Groups are not identical -> they do not contribute similar to the models
pairwise.wilcox.test(df.comparison$value,df.comparison$Var_Group,p.adj = "bonf")

tapply(df.comparison$value,df.comparison$Var_Group,summary)
tapply(df.comparison$value,df.comparison$Var_Group,IQR)
tapply(df.comparison$value,df.comparison$Var_Group,median)
tapply(df.comparison$value,df.comparison$Var_Group,mean)
tapply(df.comparison$value,df.comparison$Var_Group,sd)

# mulitple t-test to compare single MV vs. AV for variable groups
tapply(df.comparison$value[df.comparison$Var_Group=="LONG"],df.comparison$set.habitat[df.comparison$Var_Group=="LONG"],summary)
tapply(df.comparison$value[df.comparison$Var_Group=="LONG"],df.comparison$set.habitat[df.comparison$Var_Group=="LONG"],mean)
tapply(df.comparison$value[df.comparison$Var_Group=="LONG"],df.comparison$set.habitat[df.comparison$Var_Group=="LONG"],sd)
wilcox.test(df.comparison$value[df.comparison$Var_Group=="LONG" & df.comparison$set.habitat=="MV"],
            df.comparison$value[df.comparison$Var_Group=="LONG" & df.comparison$set.habitat=="AV"],
            alternative="two.sided")

tapply(df.comparison$value[df.comparison$Var_Group=="BANK"],df.comparison$set.habitat[df.comparison$Var_Group=="BANK"],summary)
tapply(df.comparison$value[df.comparison$Var_Group=="BANK"],df.comparison$set.habitat[df.comparison$Var_Group=="BANK"],mean)
tapply(df.comparison$value[df.comparison$Var_Group=="BANK"],df.comparison$set.habitat[df.comparison$Var_Group=="BANK"],sd)
wilcox.test(df.comparison$value[df.comparison$Var_Group=="BANK" & df.comparison$set.habitat=="MV"],
            df.comparison$value[df.comparison$Var_Group=="BANK" & df.comparison$set.habitat=="AV"],
            alternative="two.sided")

tapply(df.comparison$value[df.comparison$Var_Group=="PROFILE"],df.comparison$set.habitat[df.comparison$Var_Group=="PROFILE"],summary)
tapply(df.comparison$value[df.comparison$Var_Group=="PROFILE"],df.comparison$set.habitat[df.comparison$Var_Group=="PROFILE"],mean)
tapply(df.comparison$value[df.comparison$Var_Group=="PROFILE"],df.comparison$set.habitat[df.comparison$Var_Group=="PROFILE"],sd)
wilcox.test(df.comparison$value[df.comparison$Var_Group=="PROFILE" & df.comparison$set.habitat=="MV"],
            df.comparison$value[df.comparison$Var_Group=="PROFILE" & df.comparison$set.habitat=="AV"],
            alternative="two.sided")

tapply(df.comparison$value[df.comparison$Var_Group=="BED"],df.comparison$set.habitat[df.comparison$Var_Group=="BED"],summary)
tapply(df.comparison$value[df.comparison$Var_Group=="BED"],df.comparison$set.habitat[df.comparison$Var_Group=="BED"],mean)
tapply(df.comparison$value[df.comparison$Var_Group=="BED"],df.comparison$set.habitat[df.comparison$Var_Group=="BED"],sd)
wilcox.test(df.comparison$value[df.comparison$Var_Group=="BED" & df.comparison$set.habitat=="MV"],
            df.comparison$value[df.comparison$Var_Group=="BED" & df.comparison$set.habitat=="AV"],
            alternative="two.sided")

# Sum of contribution
head(df.comparison)
df.comparison.cast1 <- dcast(df.comparison,Var_Group~distance+set.habitat,value.var="value",fun.aggregate=sum)
df.comparison.cast2a <- dcast(df.comparison,Var_Group~distance,value.var="value",fun.aggregate=sum)
df.comparison.cast2b <- dcast(df.comparison,Var_Group~set.habitat,value.var="value",fun.aggregate=sum)
df.comparison.cast3 <- tapply(df.comparison$value,df.comparison$Var_Group,sum)

# Number selected
df.comparison.cast_times_selected <- dcast(df.comparison,Var_Group~set.habitat,value.var="value",fun.aggregate=function(x) sum(x>0))       
summary(df.comparison)

# Correlation with distance
df.comparison.cast4_sum <- dcast(df.comparison,distance~Var_Group,value.var="value",fun.aggregate=sum)
df.comparison.cast4_mean <- dcast(df.comparison,distance~Var_Group,value.var="value",fun.aggregate=mean)

cor.test(df.comparison.cast4_sum$TOPO,as.numeric(as.character(df.comparison.cast4_sum$distance)),MVmethod="spearman")
plot(df.comparison.cast4_sum$TOPO,as.numeric(as.character(df.comparison.cast4_sum$distance)))
cor.test(df.comparison.cast4_mean$TOPO,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
plot(df.comparison.cast4_mean$TOPO,as.numeric(as.character(df.comparison.cast4_mean$distance)))

cor.test(df.comparison.cast4_sum$BANK,as.numeric(as.character(df.comparison.cast4_sum$distance)),MVmethod="spearman")
plot(df.comparison.cast4_sum$BANK,as.numeric(as.character(df.comparison.cast4_sum$distance)))
cor.test(df.comparison.cast4_mean$BANK,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
plot(df.comparison.cast4_mean$BANK,as.numeric(as.character(df.comparison.cast4_mean$distance)))

cor.test(df.comparison.cast4_sum$PROFILE,as.numeric(as.character(df.comparison.cast4_sum$distance)),MVmethod="spearman")
plot(df.comparison.cast4_sum$PROFILE,as.numeric(as.character(df.comparison.cast4_sum$distance)))
cor.test(df.comparison.cast4_mean$PROFILE,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
plot(df.comparison.cast4_mean$PROFILE,as.numeric(as.character(df.comparison.cast4_mean$distance)))

cor.test(df.comparison.cast4_sum$BED,as.numeric(as.character(df.comparison.cast4_sum$distance)),MVmethod="spearman")
plot(df.comparison.cast4_sum$BED,as.numeric(as.character(df.comparison.cast4_sum$distance)))
cor.test(df.comparison.cast4_mean$BED,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
plot(df.comparison.cast4_mean$BED,as.numeric(as.character(df.comparison.cast4_mean$distance)))

cor.test(df.comparison.cast4_sum$LONG,as.numeric(as.character(df.comparison.cast4_sum$distance)),MVmethod="spearman")
plot(df.comparison.cast4_sum$LONG,as.numeric(as.character(df.comparison.cast4_sum$distance)))
cor.test(df.comparison.cast4_mean$LONG,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
plot(df.comparison.cast4_mean$LONG,as.numeric(as.character(df.comparison.cast4_mean$distance)))

cor.test(df.comparison.cast4_sum$FLOODPLAIN,as.numeric(as.character(df.comparison.cast4_sum$distance)),MVmethod="spearman")
plot(df.comparison.cast4_sum$FLOODPLAIN,as.numeric(as.character(df.comparison.cast4_sum$distance)))
cor.test(df.comparison.cast4_mean$FLOODPLAIN,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
plot(df.comparison.cast4_mean$FLOODPLAIN,as.numeric(as.character(df.comparison.cast4_mean$distance)))


### Correlation with distance for single groups
df.comparison.cast5_mean <- dcast(df.comparison,distance~Var_Group+set.habitat,value.var="value",fun.aggregate=mean)

cor.test(df.comparison.cast5_mean$TOPO_AV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
cor.test(df.comparison.cast5_mean$TOPO_MV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")

cor.test(df.comparison.cast5_mean$PROFILE_AV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
cor.test(df.comparison.cast5_mean$PROFILE_MV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")


cor.test(df.comparison.cast5_mean$BED_AV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
cor.test(df.comparison.cast5_mean$BED_MV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")

cor.test(df.comparison.cast5_mean$FLOODPLAIN_AV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")
cor.test(df.comparison.cast5_mean$FLOODPLAIN_MV,as.numeric(as.character(df.comparison.cast4_mean$distance)),MVmethod="spearman")





