# Plotting contribution single variables of the final BRT models
# 
# Author: Johannes Radinger
###############################################################################




##### Analyse VARIABLE CONTRIBUTION #######

library("reshape")
library(ggplot2)
library(gridExtra)
library(xlsx)
library(plyr)

#Resultsdir
maindir <- "/path/to/data/Treene/SDM_Treene/SDM_BRT_Treene/"
results_dir <- paste(maindir,"Results/",sep="")

VC.df <- readRDS(file = paste(results_dir,"VC.df.rds",sep=""))

####### Plots #############
#### incl_TOPO VC - plot ####
# Prepare plot.df, set.habitat and + topo
plot.df.incl_TOPO <- droplevels(VC.df[#VC.df$set.habitat=="A" & 
                                        VC.df$set.topology=="+",])
# order factor levels (A=MV=measured variables; FE=AV=assessed variables)
plot.df.incl_TOPO$set.habitat <- factor(plot.df.incl_TOPO$set.habitat,
                                   levels = c("A","FE"),
                                   labels = c("MV","AV"))
plot.df.incl_TOPO$Var_Code <- with(plot.df.incl_TOPO, reorder(Var_Code,value,function(x) -mean(x)))
plot.df.incl_TOPO$Var_Group <- factor(plot.df.incl_TOPO$Var_Group,levels=c("TOPO","PROFILE","BED","BANK","LONG","FLOODPLAIN"))
plot.df.incl_TOPO$distance <- factor(plot.df.incl_TOPO$distance,
                                   levels=c("point","d200bar","d1000bar","d2500bar","d4000bar"),
                                   labels=c("0","200","1000","2500","4000"))

plot.VC.incl_TOPO <- ggplot(plot.df.incl_TOPO,aes(x=set.habitat, y=value, fill=set.habitat ))+
    #geom_point(aes(x=Var_Group, y=value))+
    geom_jitter(position=position_jitter(width=.2),alpha=0.3)+
    geom_boxplot(fatten=1,outlier.size=0,alpha=0.8)+
    #geom_violin(trim=TRUE, scale="equal",alpha=0)+
  	scale_y_continuous("% Variable contribution",trans="sqrt",breaks=c(1,10,25,50),labels=c(1,10,25,50))+
    #scale_y_continuous("% Variable contribution",limits=c(0,10),breaks=c(1,10),labels=c(1,10))+
    #scale_y_log10("% Variable contribution")+
    scale_x_discrete(labels="")+
  	facet_grid(distance~Var_Group)+
    scale_fill_grey(start=0.7, end=1)+
		theme_bw()+
		theme(legend.position = "bottom",
        legend.direction = "horizontal",
				legend.title = element_blank(),
				axis.title.x = element_blank(),
				axis.ticks.x = element_blank(),
				axis.text.x = element_text(angle=90, hjust=1, vjust=0.5),
		    #axis.title.y = element_blank(),
				panel.grid.major = element_blank(),
			  #strip.text.x=element_blank(),
        #strip.background=element_blank(),
		    panel.grid.minor= element_blank())

pdf(paste(results_dir,"variable_contribution_incl_TOPO.pdf",sep=""))
print(plot.VC.incl_TOPO)
dev.off()


